.. _developer_guide_add_estimators:

======================
Adding a New Estimator
======================

Please use the extension templates below to implement new estimators. In addition to following the templates,
please ensure that code also meets ``sktime's`` :ref:`documentation <developer_guide_documentation>` standards.

Forecasting
===========

.. literalinclude:: ../../../extension_templates/forecasting.py
    :language: python
